@@ -1470,7 +1470,23 @@ void test2 (void)
                 "dummyhost.com/host/relative/link?with=params") );
     delete(pack);
 
-    
+    // Redirect to a https page
+    std::string movedpage3 =
+        "HTTP/1.1 302 Moved\r\n"
+        "Location: https://secure.com/login.html\r\n"
+        "\r\n";
+     
+     make_html_file( "./movedfile3", movedpage3 );
+     
+     pack = make_package("http://localhost:9036/"
+        "cproxydebug-verbose/"
+        "YYY/ZZZ/200/"
+        "dummyhost.com/rawtestfile/movedfile3",0);
+     pack->router(router).move();
+     YAZ_CHECK( check_response_code(pack, 400) );
+     delete(pack);
+     
+     
     // Test that the package can get to the bounce filter, and that the request
     // is properly deproxified at that point.
     pack = make_package("http://localhost:9036/"
@@ -1501,7 +1517,6 @@ void test2 (void)
       "url2%3Dhttp%3A%2F%2Flocalhost%3A9036%2FYYY%2FZZZ%2F200%2Fdummyhost.com%2Ftestfile%2Ffile1.html" ) );
     delete(pack);
 
-#if 1
     // MP-482
     pack = make_package("http:/localhost:9036/"
           //  "cproxydebug-verbose-dump/"
@@ -1512,7 +1527,6 @@ void test2 (void)
     pack->router(router).move();
     YAZ_CHECK( check_response_code(pack, 400) );
     delete(pack);
-#endif
 
     remove_dump_dir( "./cf.200.dump" );  
     
